==> jc-1.4.0.tar.gz: java/io/FileReader.h <==
// public class java.io.FileReader

// class file dependencies
// @dep_class 42380f6d5e9ae354 java_io_FileReader
// @dep_class f5b355df85c1991d java_io_InputStreamReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStreamReader

#include "java/io/InputStreamReader.h"

#ifndef _JC_java_io_FileReader_H_
#define _JC_java_io_FileReader_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FileReader$sub_refs	_jc_java_io_FileReader$sub_refs;
typedef struct _jc_java_io_FileReader$sub_nonrefs	_jc_java_io_FileReader$sub_nonrefs;
typedef struct _jc_java_io_FileReader$refs	_jc_java_io_FileReader$refs;
typedef struct _jc_java_io_FileReader$nonrefs	_jc_java_io_FileReader$nonrefs;
typedef struct _jc_java_io_FileReader$object	_jc_java_io_FileReader$object;

typedef const struct _jc_java_io_FileReader$vmethods	_jc_java_io_FileReader$vmethods;
typedef const struct _jc_java_io_FileReader$vtable	_jc_java_io_FileReader$vtable;
typedef const struct _jc_java_io_FileReader$vtype	_jc_java_io_FileReader$vtype;

// Constructors
extern void _jc_java_io_FileReader$method$_init$538ee07130435a5e(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_io_File$object *);
extern void _jc_java_io_FileReader$method$_init$0c8bd339d1fd1424(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_io_FileDescriptor$object *);
extern void _jc_java_io_FileReader$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_io_FileReader$vmethods {
};

// Vtable
struct _jc_java_io_FileReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_InputStreamReader$vmethods	java_io_InputStreamReader;
	_jc_java_io_FileReader$vmethods	java_io_FileReader;
};

// Vtype
struct _jc_java_io_FileReader$vtype {
	_jc_type			type;
	_jc_java_io_FileReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_FileReader$refs {
    _jc_java_io_FileReader$sub_refs	java_io_FileReader;
    _jc_java_io_InputStreamReader$sub_refs	java_io_InputStreamReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_InputStreamReader$sub_nonrefs	java_io_InputStreamReader;
    _jc_java_io_FileReader$sub_nonrefs	java_io_FileReader;
};

// Object instance structure
struct _jc_java_io_FileReader$object {
	_jc_java_io_FileReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileReader$vtype	*vtype;
	_jc_java_io_FileReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileReader$vtype _jc_java_io_FileReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileReader$class_object;

#endif	/* _JC_java_io_FileReader_H_ */

==> jc-1.4.6.tar.gz: java/io/FileReader.h <==
// public class java.io.FileReader

// class file dependencies
// @dep_class 42380f6d5e9ae354 java_io_FileReader
// @dep_class 30159d8092563292 java_io_InputStreamReader
// @dep_class 688afb20bd4c4e01 java_io_Reader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStreamReader

#include "java/io/InputStreamReader.h"

#ifndef _JC_java_io_FileReader_H_
#define _JC_java_io_FileReader_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileDescriptor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FileReader$sub_refs	_jc_java_io_FileReader$sub_refs;
typedef struct _jc_java_io_FileReader$sub_nonrefs	_jc_java_io_FileReader$sub_nonrefs;
typedef struct _jc_java_io_FileReader$refs	_jc_java_io_FileReader$refs;
typedef struct _jc_java_io_FileReader$nonrefs	_jc_java_io_FileReader$nonrefs;
typedef struct _jc_java_io_FileReader$object	_jc_java_io_FileReader$object;

typedef const struct _jc_java_io_FileReader$vmethods	_jc_java_io_FileReader$vmethods;
typedef const struct _jc_java_io_FileReader$vtable	_jc_java_io_FileReader$vtable;
typedef const struct _jc_java_io_FileReader$vtype	_jc_java_io_FileReader$vtype;

// Constructors
extern void _jc_java_io_FileReader$method$_init$538ee07130435a5e(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileReader$method$_init$0c8bd339d1fd1424(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_io_FileDescriptor$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FileReader$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_FileReader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_FileReader$vmethods {
};

// Vtable
struct _jc_java_io_FileReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Reader$vmethods	java_io_Reader;
	_jc_java_io_InputStreamReader$vmethods	java_io_InputStreamReader;
	_jc_java_io_FileReader$vmethods	java_io_FileReader;
};

// Vtype
struct _jc_java_io_FileReader$vtype {
	_jc_type			type;
	_jc_java_io_FileReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FileReader$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_FileReader$refs {
    _jc_java_io_FileReader$sub_refs	java_io_FileReader;
    _jc_java_io_InputStreamReader$sub_refs	java_io_InputStreamReader;
    _jc_java_io_Reader$sub_refs	java_io_Reader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FileReader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FileReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Reader$sub_nonrefs	java_io_Reader;
    _jc_java_io_InputStreamReader$sub_nonrefs	java_io_InputStreamReader;
    _jc_java_io_FileReader$sub_nonrefs	java_io_FileReader;
};

// Object instance structure
struct _jc_java_io_FileReader$object {
	_jc_java_io_FileReader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FileReader$vtype	*vtype;
	_jc_java_io_FileReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FileReader$vtype _jc_java_io_FileReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FileReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FileReader$class_object;

#endif	/* _JC_java_io_FileReader_H_ */
